@@ -4,8 +4,6 @@ sys.path.append("..")
 from sympy import Derivative, Symbol, Function, exp, Rational, log, \
     dsolve
 
-from sympy.modules.printing import print_pygame
-
 import relativity
 
 
@@ -26,16 +24,15 @@ def eq3():
     r = Symbol("r")
     e = relativity.Rmn.dd(2,2)
     e = e.subs(relativity.nu(r), -relativity.lam(r))
-    print e
-    #print dsolve(e, [relativity.lam(r)])
+    print dsolve(e, [relativity.lam(r)])
 
 def eq4():
     r = Symbol("r")
     e = relativity.Rmn.dd(3,3)
     e = e.subs(relativity.nu(r), -relativity.lam(r))
-    print e
-    #print dsolve(e, [relativity.lam(r)])
+    print dsolve(e, [relativity.lam(r)])
 
 eq1()
-#eq2()
+eq2()
+#eq3()
 #eq4()
