@@ -8,5 +8,5 @@ e=(a+2*b)**5
 print e
 print e.diff(a)
 print e.diff(b)
-print e.diff(b).diffn(a,3)
-print e.expand().diff(b).diffn(a,3)
+print e.diff(b).diff(a,3)
+print e.expand().diff(b).diff(a,3)
