@@ -4,12 +4,12 @@ import sys
 sys.path.append("..")
 
 from sympy import *
-from sympy.modules.printing import print_gtk
+from sympy.printing import print_gtk
 
 x = Symbol('x')
 
-l1 = limit(sin(x)/x, x, 0, evaluate=False)
-print_gtk(l1)
+#l1 = limit(sin(x)/x, x, 0, evaluate=False)
+#print_gtk(l1)
 
 l2 = integrate(exp(x), (x,0,1), evaluate=False)
 print_gtk(l2)
